@@ -1,14 +1,14 @@
 #ifndef FASTREAD_COLLECTOR_H_
 #define FASTREAD_COLLECTOR_H_
 
-#include <Rcpp.h>
-#include <boost/shared_ptr.hpp>
+#include "DateTime.h"
+#include "DateTimeParser.h"
 #include "Iconv.h"
 #include "LocaleInfo.h"
 #include "Token.h"
 #include "Warnings.h"
-#include "DateTime.h"
-#include "DateTimeParser.h"
+#include <Rcpp.h>
+#include <boost/shared_ptr.hpp>
 
 class Collector;
 typedef boost::shared_ptr<Collector> CollectorPtr;
@@ -21,60 +21,61 @@ protected:
   int n_;
 
 public:
-  Collector(SEXP column, Warnings* pWarnings = NULL):
-      column_(column), pWarnings_(pWarnings), n_(0)
-  {
-  }
+  Collector(SEXP column, Warnings* pWarnings = NULL)
+      : column_(column), pWarnings_(pWarnings), n_(0) {}
 
-  virtual ~Collector() {};
+  virtual ~Collector(){};
 
-  virtual void setValue(int i, const Token& t) =0;
+  virtual void setValue(int i, const Token& t) = 0;
+  virtual void setValue(int i, const std::string& s){}; // nocov
+  virtual void setValue(int i, size_t st){};            // nocov
 
-  virtual Rcpp::RObject vector() {
-    return column_;
-  };
+  virtual Rcpp::RObject vector() { return column_; };
 
-  virtual bool skip() {
-    return false;
-  }
+  virtual bool skip() { return false; }
 
-  int size() {
-    return n_;
-  }
+  int size() { return n_; }
 
   void resize(int n) {
+    // Rcpp::Rcerr << "Resizing to: " << n << std::endl;
     if (n == n_)
       return;
 
+    if (column_ == R_NilValue)
+      return;
+
+    if (n > 0 && n < n_) {
+      SETLENGTH(column_, n);
+      SET_TRUELENGTH(column_, n);
+    } else {
+      column_ = Rf_lengthgets(column_, n);
+    }
     n_ = n;
-    column_ = Rf_lengthgets(column_, n);
   }
 
-  void clear() {
-    resize(0);
-  }
+  void clear() { resize(0); }
 
-  void setWarnings(Warnings* pWarnings) {
-    pWarnings_ = pWarnings;
-  }
+  void setWarnings(Warnings* pWarnings) { pWarnings_ = pWarnings; }
 
   inline void warn(int row, int col, std::string expected, std::string actual) {
     if (pWarnings_ == NULL) {
       Rcpp::warning(
-        "[%i, %i]: expected %s, but got '%s'",
-        row + 1, col + 1, expected, actual);
+          "[%i, %i]: expected %s, but got '%s'",
+          row + 1,
+          col + 1,
+          expected,
+          actual);
       return;
     }
 
     pWarnings_->addWarning(row, col, expected, actual);
   }
-  inline void warn(int row, int col, std::string expected,
-                   SourceIterators actual) {
+  inline void
+  warn(int row, int col, std::string expected, SourceIterators actual) {
     warn(row, col, expected, std::string(actual.first, actual.second));
   }
 
   static CollectorPtr create(Rcpp::List spec, LocaleInfo* pLocale);
-
 };
 
 // Character -------------------------------------------------------------------
@@ -83,9 +84,8 @@ class CollectorCharacter : public Collector {
   Iconv* pEncoder_;
 
 public:
-  CollectorCharacter(Iconv* pEncoder):
-    Collector(Rcpp::CharacterVector()),
-    pEncoder_(pEncoder) {}
+  CollectorCharacter(Iconv* pEncoder)
+      : Collector(Rcpp::CharacterVector()), pEncoder_(pEncoder) {}
   void setValue(int i, const Token& t);
   void setValue(int i, const std::string& s);
 };
@@ -97,12 +97,8 @@ class CollectorDate : public Collector {
   DateTimeParser parser_;
 
 public:
-  CollectorDate(LocaleInfo* pLocale, const std::string& format):
-    Collector(Rcpp::NumericVector()),
-    format_(format),
-    parser_(pLocale)
-  {
-  }
+  CollectorDate(LocaleInfo* pLocale, const std::string& format)
+      : Collector(Rcpp::NumericVector()), format_(format), parser_(pLocale) {}
 
   void setValue(int i, const Token& t);
 
@@ -110,7 +106,6 @@ public:
     column_.attr("class") = "Date";
     return column_;
   };
-
 };
 
 // Date time -------------------------------------------------------------------
@@ -121,13 +116,11 @@ class CollectorDateTime : public Collector {
   std::string tz_;
 
 public:
-  CollectorDateTime(LocaleInfo* pLocale, const std::string& format):
-    Collector(Rcpp::NumericVector()),
-    format_(format),
-    parser_(pLocale),
-    tz_(pLocale->tz_)
-  {
-  }
+  CollectorDateTime(LocaleInfo* pLocale, const std::string& format)
+      : Collector(Rcpp::NumericVector()),
+        format_(format),
+        parser_(pLocale),
+        tz_(pLocale->tz_) {}
 
   void setValue(int i, const Token& t);
 
@@ -136,15 +129,16 @@ public:
     column_.attr("tzone") = tz_;
     return column_;
   };
-
 };
 
 class CollectorDouble : public Collector {
   char decimalMark_;
+
 public:
-  CollectorDouble(char decimalMark): Collector(Rcpp::NumericVector()),
-      decimalMark_(decimalMark) {}
+  CollectorDouble(char decimalMark)
+      : Collector(Rcpp::NumericVector()), decimalMark_(decimalMark) {}
   void setValue(int i, const Token& t);
+  void setValue(int i, size_t st);
 };
 
 class CollectorFactor : public Collector {
@@ -157,9 +151,15 @@ class CollectorFactor : public Collector {
   void insert(int i, Rcpp::String str, const Token& t);
 
 public:
-  CollectorFactor(Iconv* pEncoder, Rcpp::Nullable<Rcpp::CharacterVector> levels, bool ordered, bool includeNa):
-      Collector(Rcpp::IntegerVector()), pEncoder_(pEncoder), ordered_(ordered), includeNa_(includeNa)
-  {
+  CollectorFactor(
+      Iconv* pEncoder,
+      Rcpp::Nullable<Rcpp::CharacterVector> levels,
+      bool ordered,
+      bool includeNa)
+      : Collector(Rcpp::IntegerVector()),
+        pEncoder_(pEncoder),
+        ordered_(ordered),
+        includeNa_(includeNa) {
     implicitLevels_ = levels.isNull();
     if (!implicitLevels_) {
       Rcpp::CharacterVector lvls = Rcpp::CharacterVector(levels);
@@ -182,7 +182,8 @@ public:
 
   Rcpp::RObject vector() {
     if (ordered_) {
-      column_.attr("class") = Rcpp::CharacterVector::create("ordered", "factor");
+      column_.attr("class") =
+          Rcpp::CharacterVector::create("ordered", "factor");
     } else {
       column_.attr("class") = "factor";
     }
@@ -200,13 +201,13 @@ public:
 
 class CollectorInteger : public Collector {
 public:
-  CollectorInteger(): Collector(Rcpp::IntegerVector()) {}
+  CollectorInteger() : Collector(Rcpp::IntegerVector()) {}
   void setValue(int i, const Token& t);
 };
 
 class CollectorLogical : public Collector {
 public:
-  CollectorLogical(): Collector(Rcpp::LogicalVector()) {}
+  CollectorLogical() : Collector(Rcpp::LogicalVector()) {}
   void setValue(int i, const Token& t);
 };
 
@@ -214,28 +215,23 @@ class CollectorNumeric : public Collector {
   char decimalMark_, groupingMark_;
 
 public:
-  CollectorNumeric(char decimalMark, char groupingMark):
-    Collector(Rcpp::NumericVector()),
-    decimalMark_(decimalMark),
-    groupingMark_(groupingMark) {}
+  CollectorNumeric(char decimalMark, char groupingMark)
+      : Collector(Rcpp::NumericVector()),
+        decimalMark_(decimalMark),
+        groupingMark_(groupingMark) {}
   void setValue(int i, const Token& t);
   bool isNum(char c);
 };
 
 // Time ---------------------------------------------------------------------
 
-
 class CollectorTime : public Collector {
   std::string format_;
   DateTimeParser parser_;
 
 public:
-  CollectorTime(LocaleInfo* pLocale, const std::string& format):
-    Collector(Rcpp::NumericVector()),
-    format_(format),
-    parser_(pLocale)
-  {
-  }
+  CollectorTime(LocaleInfo* pLocale, const std::string& format)
+      : Collector(Rcpp::NumericVector()), format_(format), parser_(pLocale) {}
 
   void setValue(int i, const Token& t);
 
@@ -244,7 +240,6 @@ public:
     column_.attr("units") = "secs";
     return column_;
   };
-
 };
 
 // Skip ---------------------------------------------------------------------
@@ -253,9 +248,7 @@ class CollectorSkip : public Collector {
 public:
   CollectorSkip() : Collector(R_NilValue) {}
   void setValue(int i, const Token& t) {}
-  bool skip() {
-    return true;
-  }
+  bool skip() { return true; }
 };
 
 // Raw -------------------------------------------------------------------------
@@ -265,13 +258,13 @@ public:
   void setValue(int i, const Token& t);
 };
 
-
-
 // Helpers ---------------------------------------------------------------------
 
-std::vector<CollectorPtr> collectorsCreate(Rcpp::ListOf<Rcpp::List> specs, LocaleInfo* pLocale);
+std::vector<CollectorPtr>
+collectorsCreate(Rcpp::ListOf<Rcpp::List> specs, LocaleInfo* pLocale);
 void collectorsResize(std::vector<CollectorPtr>& collectors, int n);
 void collectorsClear(std::vector<CollectorPtr>& collectors);
-std::string collectorGuess(Rcpp::CharacterVector input, Rcpp::List locale_);
+std::string collectorGuess(
+    Rcpp::CharacterVector input, Rcpp::List locale_, bool guessInteger = false);
 
 #endif
